Eine Preisgabe sensibler Daten (auch bekannt als *Sensitive Data Exposure*) liegt vor, wenn eine Anwendung sensible Informationen nicht angemessen schützt, die dann möglicherweise an Parteien weitergegeben werden, die keinen Zugang zu ihnen haben sollten.

Zu den sensiblen Daten können anwendungsbezogene Informationen wie Sitzungs-Token, Dateinamen, Stack-Traces oder vertrauliche Informationen wie Passwörter, Kreditkartendaten, sensible Gesundheitsdaten, private Kommunikation, geistiges Eigentum, Metadaten, der Quellcode des Produkts usw. gehören.

Unabhängig davon, welche Sicherheitslücke die Offenlegung der Informationen verursacht, sind alle Teile des Dienstes potenziell gefährdet.
Die Preisgabe sensibler Informationen kann in Datenbanken, Betriebssystemen und Netzwerkgeräten auftreten.
Besonders häufig tritt sie in Webanwendungen auf, wie in [OWASP's Top 10](https://owasp.org/Top10/A04_2021-Insecure_Design/) hervorgehoben wird, in der die Preisgabe sensibler Informationen als Teil des Sicherheitsrisikos *Insecure Design* für Webanwendungen aufgeführt ist, das es zu beachten gilt.